##  Step 5: Use Filters in the Filter Sidebar
Filters located in the filter sidebar within the Reports section of the SAP LeanIX user interface enable you to customize the data shown in your custom reports. By using these filters, you can dynamically modify the data that populates your custom report, thereby ensuring that the report accurately represents the insights you're seeking.
Experiment with these filters to see how they impact the data shown in your custom report.
